@@ -258,3 +258,7 @@ class LoadMaster(HttpClient):
         params = {"passwd": password}
         response = self._get('/set_initial_password', parameters=params)
         return send_response(response)
+
+    def kill_asl_instance(self):
+        response = self._get('/killaslinstance')
+        return send_response(response)
